==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QSharedMemory_shell.h <==
#ifndef QSHAREDMEMORY_SHELL_H
#define QSHAREDMEMORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCore/qsharedmemory.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QSharedMemory_shell : public QSharedMemory, public QtJambiShellInterface
{
public:
    QSharedMemory_shell(QObject* parent0 = nullptr);
    QSharedMemory_shell(const QString& key0, QObject* parent1 = nullptr);
    ~QSharedMemory_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSharedMemory_access : public QSharedMemory
{
};

#endif // QSHAREDMEMORY_SHELL_H

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QSharedMemory_shell.h <==
#ifndef QSHAREDMEMORY_SHELL_H
#define QSHAREDMEMORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<QtCore/qsharedmemory.h>)
#include <QtCore/qsharedmemory.h>
#endif
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


#if (QT_VERSION_MAJOR==5 && !defined(QT_NO_SHAREDMEMORY)) || QT_CONFIG(sharedmemory)

class QSharedMemory_shell : public QSharedMemory, public QtJambiShellInterface
{
public:
    QSharedMemory_shell(QObject* parent0 = nullptr);
    QSharedMemory_shell(const QString& key0, QObject* parent1 = nullptr);
    ~QSharedMemory_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSharedMemory_access : public QSharedMemory
{
};

#endif // (QT_VERSION_MAJOR==5 && !defined(QT_NO_SHAREDMEMORY)) || QT_CONFIG(sharedmemory)
#endif // QSHAREDMEMORY_SHELL_H
